# OpenBB Government US Provider

This extension integrates the [US Government](https://data.gov) data provider into the OpenBB Platform.

## Installation

To install the extension:

```bash
pip install openbb-us-government
```

Documentation available [here](https://docs.openbb.co/platform/developer_guide/contributing).
